PageResult class
The result of generating a page: the files created and how (or whether) its route was registered as a child of the feature route.
Constructors
-
PageResult({required List<
GeneratedFile> files, required RouteWiring routeWiring}) -
const
Properties
-
files
→ List<
GeneratedFile> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- routeWiring → RouteWiring
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited